REM --------------------------------------------------------------------------
REM File:        initGEN1.sql
REM
REM Autor:       Martin Zahn, Akadia AG, 14.03.2010
REM
REM Purpose:     Create database GEN1
REM
REM Location:    $ORACLE_HOME/dbs
REM
REM Notes:       On Production Systems you should not set "AUTOEXTEND ON",
REM              this may fill up your file system until 100%.
REM --------------------------------------------------------------------------

SPOOL /home/oracle/admin/GEN1/scripts/init$ORACLE_SID.log;
CONNECT / AS SYSDBA;

REM Startup database
REM ----------------

STARTUP NOMOUNT pfile=$ORACLE_HOME/dbs/init$ORACLE_SID.ora
REM STARTUP NOMOUNT

REM Create database
REM ---------------

CREATE DATABASE GEN1
    MAXINSTANCES 4
    MAXLOGHISTORY 100
    MAXLOGFILES 16
    MAXLOGMEMBERS 4
    MAXDATAFILES 250
    DATAFILE '/home/oracle/database/GEN1/data/system_GEN1_01.dbf' SIZE 2000M EXTENT MANAGEMENT LOCAL
    SYSAUX DATAFILE '/home/oracle/database/GEN1/data/sysaux_GEN1_01.dbf' SIZE 1000M
    SMALLFILE DEFAULT TEMPORARY TABLESPACE TEMP
       TEMPFILE '/home/oracle/database/GEN1/data/temp_GEN1_01.dbf' SIZE 500M
    SMALLFILE UNDO TABLESPACE UNDO
       DATAFILE '/home/oracle/database/GEN1/data/undo_GEN1_01.dbf' SIZE 500M
    CHARACTER SET AL32UTF8
    NATIONAL CHARACTER SET AL16UTF16
    LOGFILE
       GROUP 1 (
           '/home/oracle/database/GEN1/redo/redo_GEN1_01a.rdo',
           '/home/oracle/database/GEN1/redo/redo_GEN1_01b.rdo'
       ) size 10M,
       group 2 (
           '/home/oracle/database/GEN1/redo/redo_GEN1_02a.rdo',
           '/home/oracle/database/GEN1/redo/redo_GEN1_02b.rdo'
       ) size 10M,
       group 3 (
           '/home/oracle/database/GEN1/redo/redo_GEN1_03a.rdo',
           '/home/oracle/database/GEN1/redo/redo_GEN1_03b.rdo'
       ) size 10M,
       group 4 (
           '/home/oracle/database/GEN1/redo/redo_GEN1_04a.rdo',
           '/home/oracle/database/GEN1/redo/redo_GEN1_04b.rdo'
       ) size 10M,
       group 5 (
           '/home/oracle/database/GEN1/redo/redo_GEN1_05a.rdo',
           '/home/oracle/database/GEN1/redo/redo_GEN1_05b.rdo'
       ) size 10M
   USER SYS IDENTIFIED BY manager
   USER SYSTEM IDENTIFIED by manager;

REM Create Tablespaces
REM ------------------

CREATE SMALLFILE TABLESPACE USERS
    LOGGING
    DATAFILE '/home/oracle/database/GEN1/data/users_GEN1_01.dbf' size 50M
    EXTENT MANAGEMENT LOCAL AUTOALLOCATE
    SEGMENT SPACE MANAGEMENT AUTO;

CREATE SMALLFILE TABLESPACE DATA
    LOGGING
    DATAFILE '/home/oracle/database/GEN1/data/data_GEN1_01.dbf' size 300M
    EXTENT MANAGEMENT LOCAL AUTOALLOCATE
    SEGMENT SPACE MANAGEMENT AUTO;
ALTER DATABASE DEFAULT TABLESPACE DATA;

REM Set security for the administrative users
REM -----------------------------------------

ALTER USER sys
TEMPORARY TABLESPACE temp;
ALTER USER sys IDENTIFIED BY manager;

ALTER USER system
TEMPORARY TABLESPACE temp;
ALTER USER system IDENTIFIED BY manager;

REM Load the system scripts
REM -----------------------

DISCONNECT;
CONNECT / AS SYSDBA;
SET ECHO OFF;
SET TERMOUT ON;

REM Creates data dictionary views. This is the very first
REM Script which must be executed during Database Building
@$ORACLE_HOME/rdbms/admin/catalog.sql;

REM Parallel-Server specific views for performance queries
@$ORACLE_HOME/rdbms/admin/catparr.sql;

REM Scripts for the PL/SQL procedural option
@$ORACLE_HOME/rdbms/admin/catproc.sql;

REM Run all sql scripts for replication option
@$ORACLE_HOME/rdbms/admin/catrep.sql;

REM Collect I/O per table (actually object) statistics by
REM statistical  sampling
@$ORACLE_HOME/rdbms/admin/catio.sql;

REM This package creates a table into which references to
REM the chained rows for an IOT (Index-Only-Table) can be
REM placed using the ANALYZE command.
@$ORACLE_HOME/rdbms/admin/dbmsiotc.sql;

REM Wrap Package which creates IOTs (Index-Only-Table)
@$ORACLE_HOME/rdbms/admin/prvtiotc.plb;

REM This package allows you to display the sizes of objects in the
REM shared pool, and mark them for keeping or unkeeping in order to
REM reduce memory fragmentation.
@$ORACLE_HOME/rdbms/admin/dbmspool.sql;

REM Creates the default table for storing the output
REM of the ANALYZE LIST CHAINED ROWS command
@$ORACLE_HOME/rdbms/admin/utlchain.sql;

REM Creates the EXCEPTION table
@$ORACLE_HOME/rdbms/admin/utlexcpt.sql;

REM Grant public access to all views used by TKPROF
REM with verbose=y option
@$ORACLE_HOME/rdbms/admin/utltkprf.sql;

REM Create table PLAN_TABLE that is used by the EXPLAIN PLAN
REM statement. The explain statement requires the presence of this
REM table in order to store the descriptions of the row sources.
@$ORACLE_HOME/rdbms/admin/utlxplan.sql;

REM Create v7 style export/import views against the v8 RDBMS
REM so that EXP/IMP v7 can be used to read out data in a v8 RDBMS.
REM These views are necessary if you want to export from Oracle8
REM and import in an Oracle7 database.
@$ORACLE_HOME/rdbms/admin/catexp7.sql;

REM Create views of oracle locks
@$ORACLE_HOME/rdbms/admin/catblock.sql;

REM Print out the lock wait-for graph in a tree structured fashion
@$ORACLE_HOME/rdbms/admin/utllockt.sql;

REM Creates the default table for storing the output of the
REM analyze validate command on a partitioned table
@$ORACLE_HOME/rdbms/admin/utlvalid.sql;

REM PL/SQL Package of utility routines for raw datatypes
@$ORACLE_HOME/rdbms/admin/utlraw.sql;
@$ORACLE_HOME/rdbms/admin/prvtrawb.plb;

REM Contains the PL/SQL interface to the cryptographic toolkit
@$ORACLE_HOME/rdbms/admin/dbmsoctk.sql;
@$ORACLE_HOME/rdbms/admin/prvtoctk.plb;

REM This package provides a built-in random number generator. It is
REM faster than generators written in PL/SQL because it calls Oracle's
REMinternal random number generator.
@$ORACLE_HOME/rdbms/admin/dbmsrand.sql;

REM DBMS package specification for Oracle8 Large Object
REM This package provides routines for operations on BLOB
REM and CLOB datatypes.
@$ORACLE_HOME/rdbms/admin/dbmslob.sql;

REM Procedures for instrumenting database applications
REM DBMS_APPLICATION_INFO package spec.
@$ORACLE_HOME/rdbms/admin/dbmsapin.sql;

REM Run obfuscation toolkit script.
@$ORACLE_HOME/rdbms/admin/catobtk.sql;

REM Create Heterogeneous Services data dictionary objects.
@$ORACLE_HOME/rdbms/admin/caths.sql;

REM Create Oracle Cryptographic ToolKit
@$ORACLE_HOME/rdbms/admin/catoctk.sql;

REM Create Oracle OWM
@$ORACLE_HOME/rdbms/admin/owminst.plb;

REM Recompile all INVALID objects
REM -----------------------------
@$ORACLE_HOME/rdbms/admin/utlrp.sql;

REM Password Verify Function (Uncomment if you want to use it)
REM ----------------------------------------------------------
REM @$ORACLE_HOME/rdbms/admin/utlpwdmg.sql;

REM Create roles and users
REM ----------------------
REM GRANT EXECUTE ON dbms_pipe, dbms_alert must be granted
REM to the real users, not through a role !

DISCONNECT;
CONNECT system/manager;

ALTER USER dbsnmp
TEMPORARY TABLESPACE temp;

DISCONNECT;
CONNECT / as SYSDBA;

REM Setup PLAN_TABLE for TKPROF, SQL-Tuning
REM ---------------------------------------

GRANT DELETE,INSERT,UPDATE,SELECT ON sys.plan_table TO PUBLIC;
CREATE PUBLIC SYNONYM plan_table FOR sys.plan_table;
GRANT SELECT ON V_$PARAMETER TO PUBLIC;
GRANT SELECT ON V_$SESSION TO PUBLIC;

REM Setup AUTO TRACE for SQL*PLUS
REM -----------------------------

@$ORACLE_HOME/sqlplus/admin/plustrce.sql;
GRANT plustrace to PUBLIC;

DISCONNECT;
CONNECT system/manager;

REM SQL*PLUS product user profile
REM -----------------------------

@$ORACLE_HOME/sqlplus/admin/pupbld.sql;

REM Create Help Tables for SQL*Plus
REM -------------------------------

@$ORACLE_HOME/sqlplus/admin/help/hlpbld.sql helpus.sql;

EXIT;
